@@ -17,9 +17,7 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -79,8 +77,7 @@ struct _WnckApplicationPrivate
   guint need_emit_icon_changed : 1;
 };
 
-G_DEFINE_TYPE (WnckApplication, wnck_application, G_TYPE_OBJECT);
-#define WNCK_APPLICATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), WNCK_TYPE_APPLICATION, WnckApplicationPrivate))
+G_DEFINE_TYPE_WITH_PRIVATE (WnckApplication, wnck_application, G_TYPE_OBJECT);
 
 enum {
   NAME_CHANGED,
@@ -94,11 +91,8 @@ static void emit_icon_changed (WnckApplication *app);
 static void reset_name  (WnckApplication *app);
 static void update_name (WnckApplication *app);
 
-static void wnck_application_init        (WnckApplication      *application);
-static void wnck_application_class_init  (WnckApplicationClass *klass);
 static void wnck_application_finalize    (GObject        *object);
 
-
 static guint signals[LAST_SIGNAL] = { 0 };
 
 void
@@ -114,7 +108,7 @@ _wnck_application_shutdown_all (void)
 static void
 wnck_application_init (WnckApplication *application)
 {
-  application->priv = WNCK_APPLICATION_GET_PRIVATE (application);
+  application->priv = wnck_application_get_instance_private (application);
 
   application->priv->icon_cache = _wnck_icon_cache_new ();
   _wnck_icon_cache_set_want_fallback (application->priv->icon_cache, FALSE);
@@ -125,8 +119,6 @@ wnck_application_class_init (WnckApplicationClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (WnckApplicationPrivate));
-
   object_class->finalize = wnck_application_finalize;
 
   /**
@@ -337,18 +329,19 @@ get_icons (WnckApplication *app)
 {
   GdkPixbuf *icon;
   GdkPixbuf *mini_icon;
+  gsize normal_size;
+  gsize mini_size;
 
   icon = NULL;
   mini_icon = NULL;
+  normal_size = _wnck_get_default_icon_size ();
+  mini_size = _wnck_get_default_mini_icon_size ();
 
-  if (_wnck_read_icons (WNCK_SCREEN_XSCREEN (app->priv->screen),
+  if (_wnck_read_icons (app->priv->screen,
                         app->priv->xwindow,
                         app->priv->icon_cache,
-                        &icon,
-                        DEFAULT_ICON_WIDTH, DEFAULT_ICON_HEIGHT,
-                        &mini_icon,
-                        DEFAULT_MINI_ICON_WIDTH,
-                        DEFAULT_MINI_ICON_HEIGHT))
+                        &icon, normal_size, normal_size,
+                        &mini_icon, mini_size, mini_size))
     {
       app->priv->need_emit_icon_changed = TRUE;
       app->priv->icon_from_leader = TRUE;
@@ -373,6 +366,16 @@ get_icons (WnckApplication *app)
             !(app->priv->icon || app->priv->mini_icon));
 }
 
+void
+_wnck_application_load_icons (WnckApplication *app)
+{
+  g_return_if_fail (WNCK_IS_APPLICATION (app));
+
+  get_icons (app);
+  if (app->priv->need_emit_icon_changed)
+    emit_icon_changed (app);
+}
+
 /* Prefer to get group icon from a window of type "normal" */
 static WnckWindow*
 find_icon_window (WnckApplication *app)
@@ -413,9 +416,7 @@ wnck_application_get_icon (WnckApplication *app)
 {
   g_return_val_if_fail (WNCK_IS_APPLICATION (app), NULL);
 
-  get_icons (app);
-  if (app->priv->need_emit_icon_changed)
-    emit_icon_changed (app);
+  _wnck_application_load_icons (app);
 
   if (app->priv->icon)
     return app->priv->icon;
@@ -446,9 +447,7 @@ wnck_application_get_mini_icon (WnckApplication *app)
 {
   g_return_val_if_fail (WNCK_IS_APPLICATION (app), NULL);
 
-  get_icons (app);
-  if (app->priv->need_emit_icon_changed)
-    emit_icon_changed (app);
+  _wnck_application_load_icons (app);
 
   if (app->priv->mini_icon)
     return app->priv->mini_icon;
