@@ -16,11 +16,13 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
+#if !defined (__LIBWNCK_H_INSIDE__) && !defined (WNCK_COMPILATION)
+#error "Only <libwnck/libwnck.h> can be included directly."
+#endif
+
 #ifndef WNCK_PAGER_H
 #define WNCK_PAGER_H
 
@@ -79,52 +81,41 @@ typedef enum {
 } WnckPagerDisplayMode;
 
 /**
- * WnckPagerLayoutPolicy:
- * @WNCK_PAGER_LAYOUT_POLICY_AUTOMATIC: the #WnckPager geometry management is
- * "height for width" when in vertical orientation, or "width for height" when
- * in horizontal orientation. This is the default behavior.
- * @WNCK_PAGER_LAYOUT_POLICY_WIDTH_FOR_HEIGHT: the #WnckPager calculates its
- * width in proportion to a preset height. This can be used for a vertical
- * #WnckPager inside a horizontal panel.
- * @WNCK_PAGER_LAYOUT_POLICY_HEIGHT_FOR_WIDTH: the #WnckPager calculates its
- * height in proportion to a preset width. This can be used for a horizontal
- * #WnckPager inside a vertical panel.
+ * WnckPagerScrollMode:
+ * @WNCK_PAGER_SCROLL_2D: given that the workspaces are set up in multiple rows,
+ * scrolling on the #WnckPager will cycle through the workspaces as if on a
+ * 2-dimensional map. Example cycling order with 2 rows and 4 workspaces: 1 3 2 4.
+ * @WNCK_PAGER_SCROLL_1D: the #WnckPager will always cycle workspaces in a linear
+ * manner, irrespective of how many rows are configured. (Hint: Better for mice)
+ * Example cycling order with 2 rows and 4 workspaces: 1 2 3 4.
  *
- * Policy defining the geometry management used by a #WnckPager.
- *
- * Since: 2.32
+ * Mode defining in which order scrolling on a #WnckPager will cycle through workspaces.
  */
 typedef enum {
-  WNCK_PAGER_LAYOUT_POLICY_AUTOMATIC,
-  WNCK_PAGER_LAYOUT_POLICY_WIDTH_FOR_HEIGHT,
-  WNCK_PAGER_LAYOUT_POLICY_HEIGHT_FOR_WIDTH
-} WnckPagerLayoutPolicy;
+  WNCK_PAGER_SCROLL_2D,
+  WNCK_PAGER_SCROLL_1D
+} WnckPagerScrollMode;
 
-GType wnck_pager_get_type (void) G_GNUC_CONST;
+GType      wnck_pager_get_type           (void) G_GNUC_CONST;
 
-GtkWidget* wnck_pager_new (WnckScreen *screen);
+GtkWidget* wnck_pager_new                (void);
 
-gboolean wnck_pager_set_orientation (WnckPager         *pager,
-				     GtkOrientation     orientation);
-gboolean wnck_pager_set_n_rows   (WnckPager            *pager,
-				  int                   n_rows);
-void wnck_pager_set_display_mode (WnckPager            *pager,
-				  WnckPagerDisplayMode  mode);
-void wnck_pager_set_show_all     (WnckPager            *pager,
-				  gboolean              show_all_workspaces);
-void wnck_pager_set_shadow_type  (WnckPager	       *pager,
-				  GtkShadowType		shadow_type);
-void wnck_pager_set_layout_policy (WnckPager            *pager,
-                                   WnckPagerLayoutPolicy policy);
-
-
-#ifndef WNCK_DISABLE_DEPRECATED
-void wnck_pager_set_screen       (WnckPager            *pager,
-				  WnckScreen           *screen);
-#endif /* WNCK_DISABLE_DEPRECATED */
+gboolean   wnck_pager_set_orientation    (WnckPager            *pager,
+                                          GtkOrientation        orientation);
+gboolean   wnck_pager_set_n_rows         (WnckPager            *pager,
+                                          int                   n_rows);
+void       wnck_pager_set_display_mode   (WnckPager            *pager,
+                                          WnckPagerDisplayMode  mode);
+void       wnck_pager_set_scroll_mode    (WnckPager            *pager,
+                                          WnckPagerScrollMode   scroll_mode);
+void       wnck_pager_set_show_all       (WnckPager            *pager,
+                                          gboolean              show_all_workspaces);
+void       wnck_pager_set_shadow_type    (WnckPager            *pager,
+                                          GtkShadowType         shadow_type);
+void       wnck_pager_set_wrap_on_scroll (WnckPager            *pager,
+                                          gboolean              wrap_on_scroll);
+gboolean   wnck_pager_get_wrap_on_scroll (WnckPager            *pager);
 
 G_END_DECLS
 
 #endif /* WNCK_PAGER_H */
-
-
