@@ -45,7 +45,7 @@
  */
 
 #define FALLBACK_NAME _("Untitled window")
-#define ALL_WORKSPACES (G_MAXINT)
+#define ALL_WORKSPACES ((int) 0xFFFFFFFF)
 
 static GHashTable *window_hash = NULL;
 
@@ -166,8 +166,7 @@ struct _WnckWindowPrivate
   guint need_emit_type_changed : 1;
 };
 
-G_DEFINE_TYPE (WnckWindow, wnck_window, G_TYPE_OBJECT);
-#define WNCK_WINDOW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), WNCK_TYPE_WINDOW, WnckWindowPrivate))
+G_DEFINE_TYPE_WITH_PRIVATE (WnckWindow, wnck_window, G_TYPE_OBJECT);
 
 enum {
   NAME_CHANGED,
@@ -232,7 +231,7 @@ _wnck_window_shutdown_all (void)
 static void
 wnck_window_init (WnckWindow *window)
 {
-  window->priv = WNCK_WINDOW_GET_PRIVATE (window);
+  window->priv = wnck_window_get_instance_private (window);
 
   window->priv->icon_cache = _wnck_icon_cache_new ();
   window->priv->icon_geometry.width = -1; /* invalid cached value */
@@ -248,8 +247,6 @@ wnck_window_class_init (WnckWindowClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (WnckWindowPrivate));
-
   object_class->finalize = wnck_window_finalize;
 
   /**
@@ -1344,11 +1341,12 @@ wnck_window_is_skip_pager             (WnckWindow *window)
  **/
 void
 wnck_window_set_skip_pager (WnckWindow *window,
-                            gboolean skip)
+                            gboolean    skip)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       skip,
                       _wnck_atom_get ("_NET_WM_STATE_SKIP_PAGER"),
                       0);
@@ -1400,11 +1398,12 @@ wnck_window_is_fullscreen                 (WnckWindow *window)
  **/
 void
 wnck_window_set_skip_tasklist (WnckWindow *window,
-                               gboolean skip)
+                               gboolean    skip)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       skip,
                       _wnck_atom_get ("_NET_WM_STATE_SKIP_TASKBAR"),
                       0);
@@ -1422,11 +1421,12 @@ wnck_window_set_skip_tasklist (WnckWindow *window,
  **/
 void
 wnck_window_set_fullscreen (WnckWindow *window,
-                               gboolean fullscreen)
+                            gboolean    fullscreen)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       fullscreen,
                       _wnck_atom_get ("_NET_WM_STATE_FULLSCREEN"),
                       0);
@@ -1469,12 +1469,11 @@ wnck_window_is_sticky                 (WnckWindow *window)
  **/
 void
 wnck_window_close (WnckWindow *window,
-		   guint32     timestamp)
+                   guint32     timestamp)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_close (WNCK_SCREEN_XSCREEN (window->priv->screen),
-	       window->priv->xwindow, timestamp);
+  _wnck_close (window->priv->screen, window->priv->xwindow, timestamp);
 }
 
 /**
@@ -1517,12 +1516,12 @@ wnck_window_unminimize              (WnckWindow *window,
  * Asks the window manager to maximize @window.
  **/
 void
-wnck_window_maximize                (WnckWindow *window)
+wnck_window_maximize (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       TRUE,
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_VERT"),
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_HORZ"));
@@ -1535,12 +1534,12 @@ wnck_window_maximize                (WnckWindow *window)
  * Asks the window manager to unmaximize @window.
  **/
 void
-wnck_window_unmaximize              (WnckWindow *window)
+wnck_window_unmaximize (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       FALSE,
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_VERT"),
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_HORZ"));
@@ -1553,12 +1552,12 @@ wnck_window_unmaximize              (WnckWindow *window)
  * Asks the window manager to maximize horizontally @window.
  **/
 void
-wnck_window_maximize_horizontally   (WnckWindow *window)
+wnck_window_maximize_horizontally (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       TRUE,
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_HORZ"),
                       0);
@@ -1575,8 +1574,8 @@ wnck_window_unmaximize_horizontally (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       FALSE,
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_HORZ"),
                       0);
@@ -1589,12 +1588,12 @@ wnck_window_unmaximize_horizontally (WnckWindow *window)
  * Asks the window manager to maximize vertically @window.
  **/
 void
-wnck_window_maximize_vertically     (WnckWindow *window)
+wnck_window_maximize_vertically (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       TRUE,
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_VERT"),
                       0);
@@ -1607,12 +1606,12 @@ wnck_window_maximize_vertically     (WnckWindow *window)
  * Asks the window manager to unmaximize vertically @window.
  **/
 void
-wnck_window_unmaximize_vertically   (WnckWindow *window)
+wnck_window_unmaximize_vertically (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       FALSE,
                       _wnck_atom_get ("_NET_WM_STATE_MAXIMIZED_VERT"),
                       0);
@@ -1625,12 +1624,12 @@ wnck_window_unmaximize_vertically   (WnckWindow *window)
  * Asks the window manager to shade @window.
  **/
 void
-wnck_window_shade                   (WnckWindow *window)
+wnck_window_shade (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       TRUE,
                       _wnck_atom_get ("_NET_WM_STATE_SHADED"),
                       0);
@@ -1643,12 +1642,12 @@ wnck_window_shade                   (WnckWindow *window)
  * Asks the window manager to unshade @window.
  **/
 void
-wnck_window_unshade                 (WnckWindow *window)
+wnck_window_unshade (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       FALSE,
                       _wnck_atom_get ("_NET_WM_STATE_SHADED"),
                       0);
@@ -1669,7 +1668,7 @@ wnck_window_make_above (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  _wnck_change_state (window->priv->screen,
                       window->priv->xwindow,
                       TRUE,
                       _wnck_atom_get ("_NET_WM_STATE_ABOVE"),
@@ -1690,7 +1689,7 @@ wnck_window_unmake_above (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  _wnck_change_state (window->priv->screen,
                       window->priv->xwindow,
                       FALSE,
                       _wnck_atom_get ("_NET_WM_STATE_ABOVE"),
@@ -1710,7 +1709,7 @@ wnck_window_make_below (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  _wnck_change_state (window->priv->screen,
                       window->priv->xwindow,
                       TRUE,
                       _wnck_atom_get ("_NET_WM_STATE_BELOW"),
@@ -1731,7 +1730,7 @@ wnck_window_unmake_below (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  _wnck_change_state (window->priv->screen,
                       window->priv->xwindow,
                       FALSE,
                       _wnck_atom_get ("_NET_WM_STATE_BELOW"),
@@ -1746,12 +1745,12 @@ wnck_window_unmake_below (WnckWindow *window)
  * screen, even when the workspace or viewport scrolls.
  **/
 void
-wnck_window_stick                   (WnckWindow *window)
+wnck_window_stick (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       TRUE,
                       _wnck_atom_get ("_NET_WM_STATE_STICKY"),
                       0);
@@ -1765,12 +1764,12 @@ wnck_window_stick                   (WnckWindow *window)
  * screen when the workspace or viewport scrolls.
  **/
 void
-wnck_window_unstick                 (WnckWindow *window)
+wnck_window_unstick (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_state (WNCK_SCREEN_XSCREEN (window->priv->screen),
-		      window->priv->xwindow,
+  _wnck_change_state (window->priv->screen,
+                      window->priv->xwindow,
                       FALSE,
                       _wnck_atom_get ("_NET_WM_STATE_STICKY"),
                       0);
@@ -1787,7 +1786,7 @@ wnck_window_keyboard_move (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_keyboard_move (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  _wnck_keyboard_move (window->priv->screen,
                        window->priv->xwindow);
 }
 
@@ -1802,7 +1801,7 @@ wnck_window_keyboard_size (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_keyboard_size (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  _wnck_keyboard_size (window->priv->screen,
                        window->priv->xwindow);
 }
 
@@ -1843,8 +1842,8 @@ wnck_window_move_to_workspace (WnckWindow    *window,
   g_return_if_fail (WNCK_IS_WINDOW (window));
   g_return_if_fail (WNCK_IS_WORKSPACE (space));
 
-  _wnck_change_workspace (WNCK_SCREEN_XSCREEN (window->priv->screen),
-			  window->priv->xwindow,
+  _wnck_change_workspace (window->priv->screen,
+                          window->priv->xwindow,
                           wnck_workspace_get_number (space));
 }
 
@@ -1877,8 +1876,8 @@ wnck_window_pin (WnckWindow *window)
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_change_workspace (WNCK_SCREEN_XSCREEN (window->priv->screen),
-			  window->priv->xwindow,
+  _wnck_change_workspace (window->priv->screen,
+                          window->priv->xwindow,
                           ALL_WORKSPACES);
 }
 
@@ -1904,8 +1903,8 @@ wnck_window_unpin (WnckWindow *window)
 
   active = wnck_screen_get_active_workspace (window->priv->screen);
 
-  _wnck_change_workspace (WNCK_SCREEN_XSCREEN (window->priv->screen),
-			  window->priv->xwindow,
+  _wnck_change_workspace (window->priv->screen,
+                          window->priv->xwindow,
                           active ? wnck_workspace_get_number (active) : 0);
 }
 
@@ -1931,7 +1930,7 @@ wnck_window_activate (WnckWindow *window,
 {
   g_return_if_fail (WNCK_IS_WINDOW (window));
 
-  _wnck_activate (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  _wnck_activate (window->priv->screen,
                   window->priv->xwindow,
                   timestamp);
 }
@@ -2126,7 +2125,7 @@ get_icons (WnckWindow *window)
   normal_size = _wnck_get_default_icon_size ();
   mini_size = _wnck_get_default_mini_icon_size ();
 
-  if (_wnck_read_icons (WNCK_SCREEN_XSCREEN (window->priv->screen),
+  if (_wnck_read_icons (window->priv->screen,
                         window->priv->xwindow,
                         window->priv->icon_cache,
                         &icon, normal_size, normal_size,
